stalker.core.models.Link — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.models.Link

class `stalker.core.models.` `Link`(path='', filename='', **kwargs)

  Bases: `stalker.core.models.Entity`

  Holds data about external links.

  Links are all about to give some external information to the current entity (external to the database, so it can be something on the `Repository` or in the Web). The link type is defined by the `LinkType` object and it can be anything like General, File, Folder, WebPage, Image, ImageSequence, Movie, Text etc. (you can also use multiple `Tag` objects to adding more information, and filtering back). Again it is defined by the needs of the studio.

  Parameters: | path – The Path to the link, it can be a path to a file in the file system, or a web page. Setting path to None or an empty string is not accepted. filename – The file name part of the link url, for file sequences use “#” in place of the numerator (Nuke style). Setting filename to None or an empty string is not accepted.

  `__init__`(path='', filename='', **kwargs)

  Methods

  `__init__`(**kwargs[, path, filename]) |

  Attributes

  `code` | The code name of this object.
  `created_by` | The `User` who has created this object.
  `date_created` | A `datetime.datetime` instance showing the creation date and time of this object.
  `date_updated` | A `datetime.datetime` instance showing the update date and time of this object.
  `description` | Description of this object.
  `filename` | the filename part of the url to the link, it can not be None or
  `name` | Name of this object
  `nice_name` | Nice name of this object.
  `notes` | All the notes about this entity.
  `path` | the path part of the url to the link, it can not be None or an
  `tags` | A list of tags attached to this object.
  `type` | The type of the object.
  `updated_by` | The `User` who has updated this object.

  `path`

    the path part of the url to the link, it can not be None or an empty string, it should be a string or unicode

  `filename`

    the filename part of the url to the link, it can not be None or an empty string, it should be a string or unicode

  `code`

    The code name of this object.

    It accepts string or unicode values and any other kind of objects will be converted to string. In any update to the name attribute the code also will be updated. If the code is not initialized or given as None, it will be set to the uppercase version of the nice_name attribute. Setting the code attribute to None will reset it to the default value. The default value is the upper case form of the nice_name.

  `created_by`

    The `User` who has created this object.

  `date_created`

    A `datetime.datetime` instance showing the creation date and time of this object.

  `date_updated`

    A `datetime.datetime` instance showing the update date and time of this object.

  `description`

    Description of this object.

  `name`

    Name of this object

  `nice_name`

    Nice name of this object.

    It has the same value with the name (contextually) but with a different format like, all the white spaces replaced by underscores (“_”), all the CamelCase form will be expanded by underscore (_) characters and it is always lower case.

    There is also the `code` attribute which is simply the upper case form of `nice_name` if it is not defined differently (i.e set to another value).

  `notes`

    All the notes about this entity.

    It is a list of `Note` objects or an empty list, None will be converted to an empty list.

  `tags`

    A list of tags attached to this object.

    It is a list of `Tag` instances which shows the tags of this object

  `type`

    The type of the object.

    It is an instance of `Type` with a proper `target_entity_type`.

  `updated_by`

    The `User` who has updated this object.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »